==> ms-users-12.1.1.tgz: package/lib/utils/organization/get-organization-metadata-and-members.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const getInternalData = require('./get-internal-data');

const getOrganizationMembers = require('./get-organization-members');

const getOrganizationMetadata = require('./get-organization-metadata');

async function getOrganizationMetadataAndMembers(organizationId) {
  const organization = await getInternalData.call(this, organizationId, true);
  const members = await getOrganizationMembers.call(this, organizationId);
  const metadata = await getOrganizationMetadata.call(this, organizationId);
  return _objectSpread({}, organization, {
    metadata,
    members
  });
}

module.exports = getOrganizationMetadataAndMembers;

==> ms-users-14.13.0.tgz: package/lib/utils/organization/get-organization-metadata-and-members.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const getInternalData = require('./get-internal-data');

const getOrganizationMembers = require('./get-organization-members');

const getOrganizationMetadata = require('./get-organization-metadata');

async function getOrganizationMetadataAndMembers(organizationId) {
  const organization = await getInternalData.call(this, organizationId, true);
  const members = await getOrganizationMembers.call(this, organizationId);
  const metadata = await getOrganizationMetadata.call(this, organizationId);
  return _objectSpread(_objectSpread({}, organization), {}, {
    metadata,
    members
  });
}

module.exports = getOrganizationMetadataAndMembers;
